import { ResponseCookies } from "next/dist/server/web/spec-extension/cookies";
import { NextRequest, NextResponse } from "next/server";
import { z } from "zod";
export type RouteParamsBase = Record<string, string | string[]> | object;
export type ContextBase = object;
export type NextJSRequestHandler<RouteParams extends RouteParamsBase> = (req: NextRequest, params: {
    params: RouteParams;
}) => Promise<NextResponse> | NextResponse;
export type CookieSetArgs = Parameters<typeof ResponseCookies.prototype.set>;
export type CookieDeleteArgs = Parameters<typeof ResponseCookies.prototype.delete>;
export type EmptyZodObject = z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>;
export type RequestHandler<RouteParams, QueryParams, RequestCookies, Body, Context, Res> = (options: {
    params: RouteParams;
    query: QueryParams;
    cookies: RequestCookies;
    body: Body;
    context: Context;
    req: NextRequest;
    headers: Headers;
    setCookie: (...args: CookieSetArgs) => void;
    deleteCookie: (...args: CookieDeleteArgs) => void;
}) => Res | NextResponse | Promise<Res | NextResponse>;
export type RequestMethod = "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
export declare const RequestMethodHasBody: {
    GET: false;
    POST: true;
    PUT: true;
    PATCH: true;
    DELETE: false;
    HEAD: false;
    OPTIONS: false;
};
export type TRequestMethodHasBody = typeof RequestMethodHasBody;
export type RequestMethodWithBody = {
    [K in RequestMethod]: TRequestMethodHasBody[K] extends true ? K : never;
}[RequestMethod];
export type APIResponseWrapper<Res> = {
    status: "error";
    message: string;
} | {
    status: "ok";
    data: Res;
};
